sucodev_core library

Classes

AppButton
AppColors
AppContainer
AppDio
AppIconButton
AppImageButton
AppKey
AppManager
AppMenuButton
AppObserverScreen
AppReadmoreText
AppReplaceText
AppReplaceTextSpan
Model ReplaceSpan
AppRequiredText
AppRouteObserver
AppText
AppTextButton
AppTextField
AuthManager
BaseBloc<E, S>
BaseBloc every bloc should extend this bloc, will add helper function to fast the development process.
BaseBlocGetItPage<P extends StatefulWidget, B extends BaseBloc>
BaseBlocProviderPage<P extends StatefulWidget, B extends BaseBloc>
BaseCubit<S extends BaseCubitState>
BaseCubitState
BaseDialogContent
BaseFailure
BaseHiveLocalDataSource
BaseLocalDataSource
BaseRemoteDataSource
this implementation is done by using dio as an http library
BaseRepository
BaseState<S extends StatefulWidget>
BaseViewmodel
BlocBuilderWidget<B extends StateStreamable<S>, S>
BlocConsumerWidget<B extends StateStreamable<S>, S>
BlocFutureBuilder<T extends Bloc, D>
BlocListenerWidget<B extends StateStreamable<S>, S>
BlocProviderWidget<T extends StateStreamableSource<Object?>>
BlocStateGetIt<P extends StatefulWidget, B extends BaseBloc>
BlocStateProvider<P extends StatefulWidget, B extends BaseBloc>
BottomSheetDraggableContainer
CircularLoadingAnimation
CommonCubit
CommonHelper
CommonState
ConfirmDialogContent
ConnectivityInterceptor
ContextCallbackTriggered
DataModelWrapper<T>
DelayTween
Empty<T>
ErrorDialogContent
ErrorString
FadeAnimation
FadeAnimationState
FadeInOut
FailureCleared
FailureHappened
FutureDataModelWrapperBuilder<T extends Bloc, D>
GlobalData
GlobalKeyVariable
HelperBloc
HelperBlocEvent
HelperBlocState
HiveAdapters
IBaseLocalDataSource
IBaseLocalDataSourceHive
IBaseRemoteDataSource
IsLoading<T>
JsonDecoderInterceptor
LoadingChanged
LoadingDialogContent
LocalData<T>
LocalDataFailure<T>
MobxFutureBuilder<T>
MobxLoadingPage<T extends BaseViewmodel>
MobxState<T extends StatefulWidget, V extends BaseViewmodel>
NetworkData<T>
NetworkDataFailure<T>
NoDecimalFormatter
PageRouterCubit
PageRouterState
ProviderMobxState<T extends StatefulWidget, V extends BaseViewmodel>
ScreenValue<T>
SuccessDialogContent
SupportedLanguage
ThreeBounce
TokenConstants
UnknownErrorHappened
UpperCaseTextFormatter

Properties

appDio AppDio
getter/setter pair
CURRENCY String
final
dayOfWeek List<String>
getter/setter pair
MINI_NO_DATA_WIDGET Widget
final
months List<String>
getter/setter pair
NO_DATA_WIDGET Widget
final
serviceLocator → GetIt
final
spApp AppManager
getter/setter pair
spAuth AuthManager
getter/setter pair

Functions

commonDependencies() Future<void>
decodeJson(String? jsonString) → dynamic
initDI() Future<void>
processData<T>(dynamic responseData, Deserializer<T?>? deserializer, MapDeserializer<T?>? mapDeserializer) DataModelWrapper<T>
showConfirmDialog(BuildContext context, {String? title, String? content, String? acceptLable, VoidCallback? onAccept, VoidCallback? onReject}) Future<bool?>
showErrorDialog(BuildContext context, {String? title, String? content, VoidCallback? onAccept}) Future
showLoading({WrapAnimation? wrapToastAnimation, BackButtonBehavior? backButtonBehavior, VoidCallback? onClose, Duration? duration, Duration? animationDuration, Duration? animationReverseDuration}) → void Function()
showSuccessDialog(BuildContext context, {String? title, String? content, VoidCallback? onAccept}) Future

Typedefs

BlocBaseAsyncShowDialog<T> = Future<void> Function(BuildContext _, T state)
Bloc base screen
BlocBaseCreateCubit<T> = T Function(BuildContext _)
BlocBaseOnShowDialogDone<T> = void Function(BuildContext _, T state)
ContextCallback = void Function(BuildContext)
DatabaseSchema = List<String>
Deserializer<T> = T Function(Object?)
FormChildWidgetBuilder = Widget Function(GlobalKey<FormState> formKey)
Build child widget from app form
IdentifyCallBack<T> = String Function(T? item)
Get identity of an item
ItemRenderCallBack<T> = Widget Function(T item)
Build widget form an item of a list
MapDeserializer<T> = T Function(Map<String, dynamic>)
MapDeserializerHive<T> = T Function(Map)
NetworkRequest = Future<Response> Function()
OnItemTap<T> = void Function(T item)
On tap to an item of a list
SqlQuery = Tuple2<String, List?> Function()
ToMap<T> = Map<String, dynamic> Function()
TypeValidation<T> = String? Function(T? data)
Validator for form field
UpdateStyleCallBack = TextStyle Function(TextStyle style)
Update Text Style